<template>
	<div class="playInput hl_input">
		<div class="assembly flex">
			<el-button title="插件菜单" class="label flex items-center cursor-pointer" link>
				<img src="/static/images/wave/PlugIn.png" class="set-icon box-border" />
			</el-button>
		</div>
		<InfoDetail class="text-base" v-model="infoDetailIsShow" :item="detailMapRow"  />

		<div class="set-input">
			<!-- @input="inputText" -->

			<el-input
				ref="inputRef"
				class="relative align-bottom set-inputAnswer"
				type="textarea"
				resize="none"
				:autosize="{ minRows: 1, maxRows: 8 }"
				v-elInputFocus
				@keydown="keydownInput"
				@input="inputText"
				v-model="inputValue"
				placeholder="在这里输入您的问题开始和AI对话"
			>
			</el-input>
			<div
				v-show="tipIsShow"
				ref="tipEleRef"
				class="absolute rounded-md bg-white border border-solid border-gray-400 py-2 z-10"
				:style="{ left: popUpPosition.left + 'px', bottom: popUpPosition.bottom + 'px' }"
			>
				<div class="font-bold text-sm text-nowrap overflow-hidden text-ellipsis max-w-80 mb-1 px-2">Ctrl+数字快捷输入</div>
				<div class="text-gray-400 text-sm text-nowrap overflow-hidden text-ellipsis max-w-80 mb-1 px-2">{{ inputValue }}</div>
				<div class="max-w-96 flex flex-col">
					<div
						class="hover:bg-gray-300 py-2 cursor-pointer px-5 text-nowrap overflow-hidden text-ellipsis"
						v-for="(item, index) in similarList"
						:key="index"
						@click="similarClick(item)"
					>
						<span class="text-sm text-gray-500 pr-1.5">{{ index + 1 }}</span>
						<span> {{ item?.question }} </span>
						<!-- <span class="text-blue-400 font-bold cursor-pointer hover:underline" @click.stop="tipMetricsClick">测试是</span> -->
					</div>
				</div>
			</div>
		</div>
		<div class="h100 flex items-center">
			<div class="upload_img space-y">
				<div class="imgbox cursor-pointer flex items-center">
					<!-- <el-button title="AI看图" class="cursor-pointer" link style="margin-left: unset">
						<img src="/static/images/wave/LookImg.png" class="set-img-icon box-border" />
					</el-button> -->
					<!-- <el-button title="AI语音对话" class="cursor-pointer" link style="margin-left: unset" @click="audioChangeWord">
						<img src="/static/images/wave/HeadImg.png" class="set-img-icon box-border" />
					</el-button> -->

					<el-button title="发送" :disabled="isTalking" class="cursor-pointer" link @click="emits('sendClick')">
						<div class="send">
							<img src="/static/images/wave/QueryImg.png" />
						</div>
					</el-button>
				</div>
			</div>
		</div>
		<VoicePage
			v-model:isShow="voicePageIsShow"
			v-show="voicePageIsShow"
			@submit="(cb) => emits('sendClick', cb)"
			@updateInputValue="updateInputValue"
			:isHome="isHome"
		/>
	</div>
</template>

<script setup lang="ts">
import type { InputInstance } from 'element-plus';
import { ElMessage } from 'element-plus';
import getCaretCoordinates from 'textarea-caret';
import { computed, nextTick, ref } from 'vue';
import VoicePage from './voicePage/VoicePage.vue';
import { querySimilarityHistory } from '/@/api/ai/chat';
import { useClickOther } from '/@/hooks/useClickOther';
import InfoDetail from './InfoDetail.vue';

import { onClickOutside } from '@vueuse/core';
const emits = defineEmits(['sendClick']);
const props = defineProps(['isTalking', 'isHome']);
const voicePageIsShow = defineModel('voicePageIsShow', {
	type: Boolean,
	default: false,
});
const inputValue = defineModel({
	type: String,
});

const tipIsShow = computed(() => !!inputValue.value.trim() && similarList.value?.length > 0 && triggerShow.value);
const triggerShow = ref(false);
const inputRef = ref<InputInstance>(null);

const updateInputValue = (val) => {
	inputValue.value = val;
};
const keydownInput = (e) => {
	if (props.isTalking) return;
	const isEnterInput = !e.shiftKey && e.key == 'Enter';
	const isDigitalInput = e.ctrlKey && e.code.startsWith('Digit') && tipIsShow.value;
	if (isEnterInput || isDigitalInput) {
		e.cancelBubble = true; //ie阻止冒泡行为
		e.stopPropagation(); //Firefox阻止冒泡行为
		e.preventDefault(); //取消事件的默认动作*换行
		if (isEnterInput) {
			//以下处理发送消息代码
			emits('sendClick');
		} else if (isDigitalInput) {
			const num = Number(e.code.replace('Digit', ''));
			const mapValue = similarList.value[num - 1]?.question;
			if (mapValue) {
				inputValue.value = mapValue;
				triggerShow.value = false;
			}
		}
	}
};

const similarClick = (item) => {
	if (item.question) {
		inputValue.value = item.question;
		triggerShow.value = false;
	}
};

const tipEleRef = ref<HTMLDivElement>(null);

const popUpPosition = ref({
	left: null,
	bottom: null,
});

onClickOutside(tipEleRef, () => {
	triggerShow.value = false;
});
const inputText = (text) => {
	nextTick(() => {
		setTimeout(() => {
			const container = inputRef.value.$el;

			const textAreaEl = inputRef.value.$el.firstElementChild;
			const caret = getCaretCoordinates(textAreaEl, textAreaEl.selectionEnd);

			const bottomOffset = 10;
			const leftOffset = 9;
			popUpPosition.value.left = caret.left + leftOffset;
			popUpPosition.value.bottom = container.offsetHeight + bottomOffset;
			triggerShow.value = true;
			if (lastIsFinish) {
				querySimilarityApi(text);
			}
		}, 0);
	});
};

const similarList = ref([]);
let lastIsFinish = true;
const querySimilarityApi = async (text: string) => {
	if (!text) return;
	lastIsFinish = false;
	const res = await querySimilarityHistory({
		question: text,
	});
	lastIsFinish = true;
	const handleValues = res?.values ?? [];

	similarList.value = props.isHome ? handleValues.slice(0, 3) : handleValues;
};
const audioChangeWord = () => {
	navigator.getUserMedia(
		{ audio: true },
		function onSuccess(stream) {
			voicePageIsShow.value = true;
		},
		function onError(error) {
			ElMessage.warning('请打开麦克风权限');
		}
	);
};


//#region ======================  高亮指标点击======================
const infoDetailIsShow = ref(false);
const detailMapRow = ref(null);

const tipMetricsClick = (row) => {
	detailMapRow.value = row;
	infoDetailIsShow.value = true;
};
//#endregion
</script>
<style scoped lang="scss">
.set-waterTitle {
	line-height: 24px;
	font-weight: 500;
	font-size: 18px;
	color: #3b4066;
	vertical-align: middle;
}
strong {
	font-size: 26px;
	font-weight: 700;
	margin-right: 12px;
}
.layout-logo-medium-img {
	width: 28px;
	margin-right: 7px;
}
.pc-roleList {
	margin: 40px 0 26px;
	position: relative;
}
.modelItem {
	height: 34px;
	padding: 0 16px;
	border-radius: 17px;
	border: 1px solid #00000020;
	background-color: #f2f4f8;
	transition: background-color 0.1s, border-color 0.1s, color 0.1s;
	color: #333;
	.set-icon {
		width: 20px;
		height: 20px;
		position: relative;
	}
	.set-icon-more {
		width: 16px;
		height: 16px;
		position: relative;
	}
	span {
		margin-left: 8px;
		font-weight: 500;
		font-size: 15px;
	}
}
.modelItemActive {
	background-color: #1c86ff;
	border-color: #1c86ff;
	color: #fff;
}
.playInput {
	align-items: flex-start;
	width: 760px;
	position: relative;
	padding: 4px 4px 4px 12px;

	display: flex;
	-webkit-box-align: end;
	-ms-flex-align: end;
	align-items: flex-end;
	-webkit-box-sizing: border-box;
	box-sizing: border-box;
	border-radius: 22px;
	border: 1px solid #00000030;
	-webkit-box-shadow: 0 0 0 1px transparent, 0 3px 16px 0 #dee0f3;
	box-shadow: 0 0 0 1px transparent, 0 3px 16px 0 #dee0f3;
	-webkit-transition: border-color 0.1s ease-in-out, -webkit-box-shadow 0.1s ease-in-out;
	transition: border-color 0.1s ease-in-out, -webkit-box-shadow 0.1s ease-in-out;
	-o-transition: border-color 0.1s ease-in-out, box-shadow 0.1s ease-in-out;
	transition: border-color 0.1s ease-in-out, box-shadow 0.1s ease-in-out;
	transition: border-color 0.1s ease-in-out, box-shadow 0.1s ease-in-out, -webkit-box-shadow 0.1s ease-in-out;
	background-color: #fff;
	.assembly {
		position: relative;
		align-self: flex-end;
		margin-right: 12px;
		.label {
			height: 38px;
		}
	}
	.set-input {
		position: relative;
		vertical-align: bottom;
		font-size: 14px;
		display: inline-block;
		width: 100%;
		.set-inputAnswer {
			padding: 3px 0;
			line-height: 20px;
			border: none;
			background-color: transparent;
			color: #333;
			font-size: 15px;
			:deep(.el-textarea__inner) {
				// 去除线
				box-shadow: none;
			}
		}
		:deep(.el-input__wrapper) {
			box-shadow: unset;
		}
	}
	.upload_img {
		.imgbox {
			height: 38px;
			.set-img-icon {
				width: 38px;
				height: 38px;
				border-radius: 5px;
				transition: background-color 0.1s ease-in-out;
			}
			.send {
				width: 36px;
				height: 36px;
				border-radius: 50%;
				background-color: #2c1e1d;
				img {
					margin: 4px 0 0 -2px;
				}
			}
		}
	}
}
</style>
